@@ -375,9 +375,11 @@ Settings::Settings() {
 	rmRecordingMode = RecordingMixdown;
 	iRecordingFormat = 0;
 
-	// Codec kill-switch
+	// Special configuration options not exposed to UI
 	bDisableCELT = false;
-
+	disablePublicList = false;
+	disableConnectDialogEditing = false;
+	
 	// Config updates
 	uiUpdateCounter = 0;
 
@@ -395,6 +397,7 @@ Settings::Settings() {
 	bSuppressMacEventTapWarning = false;
 	bEnableEvdev = false;
 	bEnableXInput2 = true;
+	bEnableXboxInput = true;
 
 	for (int i=Log::firstMsgType; i<=Log::lastMsgType; ++i)
 		qmMessages.insert(i, Settings::LogConsole | Settings::LogBalloon | Settings::LogTTS);
@@ -683,8 +686,11 @@ void Settings::load(QSettings* settings_ptr) {
 	LOADENUM(rmRecordingMode, "recording/mode");
 	SAVELOAD(iRecordingFormat, "recording/format");
 
-	// Codec kill-switch
+	// Special configuration options not exposed to UI
 	SAVELOAD(bDisableCELT, "audio/disablecelt");
+	SAVELOAD(disablePublicList, "ui/disablepubliclist");
+	SAVELOAD(disableConnectDialogEditing, "ui/disableconnectdialogediting");
+	
 
 	// LCD
 	SAVELOAD(iLCDUserViewMinColWidth, "lcd/userview/mincolwidth");
@@ -698,6 +704,7 @@ void Settings::load(QSettings* settings_ptr) {
 	SAVELOAD(bSuppressMacEventTapWarning, "shortcut/mac/suppresswarning");
 	SAVELOAD(bEnableEvdev, "shortcut/linux/evdev/enable");
 	SAVELOAD(bEnableXInput2, "shortcut/x11/xinput2/enable");
+	SAVELOAD(bEnableXboxInput, "shortcut/windows/xbox/enable");
 
 	int nshorts = settings_ptr->beginReadArray(QLatin1String("shortcuts"));
 	for (int i=0; i<nshorts; i++) {
@@ -972,8 +979,10 @@ void Settings::save() {
 	SAVELOAD(rmRecordingMode, "recording/mode");
 	SAVELOAD(iRecordingFormat, "recording/format");
 
-	// Codec kill-switch
+	// Special configuration options not exposed to UI
 	SAVELOAD(bDisableCELT, "audio/disablecelt");
+	SAVELOAD(disablePublicList, "ui/disablepubliclist");
+	SAVELOAD(disableConnectDialogEditing, "ui/disableconnectdialogediting");
 
 	// LCD
 	SAVELOAD(iLCDUserViewMinColWidth, "lcd/userview/mincolwidth");
@@ -986,6 +995,7 @@ void Settings::save() {
 	SAVELOAD(bSuppressMacEventTapWarning, "shortcut/mac/suppresswarning");
 	SAVELOAD(bEnableEvdev, "shortcut/linux/evdev/enable");
 	SAVELOAD(bEnableXInput2, "shortcut/x11/xinput2/enable");
+	SAVELOAD(bEnableXboxInput, "shortcut/windows/xbox/enable");
 
 	settings_ptr->beginWriteArray(QLatin1String("shortcuts"));
 	int idx = 0;
